@@ -1,21 +1,23 @@
 package GitHub::MergeVelocity;
-our $VERSION = '0.000008';
-use strict;
-use warnings;
+
+use Moo 1.007000;
+
+our $VERSION = '0.000009';
 
 use CLDR::Number::Format::Percent     ();
 use File::HomeDir                     ();
 use GitHub::MergeVelocity::Repository ();
 use Module::Runtime qw( require_module use_module );
-use Moo 1.007000;
 use MooX::HandlesVia;
 use MooX::Options;
 use MooX::StrictConstructor;
 use Path::Tiny qw( path );
-use Pithub::PullRequests ();
-use Text::SimpleTable::AutoWidth;
+use Text::SimpleTable::AutoWidth ();
+use Pithub::PullRequests         ();
+use Pithub::Repos                ();
 use Types::Standard qw( ArrayRef Bool HashRef InstanceOf Int Str );
 use WWW::Mechanize::GZip ();
+use List::Util qw( uniq );
 
 option debug_useragent => (
     is            => 'ro',
@@ -55,11 +57,19 @@ option url => (
     is            => 'ro',
     isa           => ArrayRef,
     format        => 's@',
-    required      => 1,
+    required      => 0,
     documentation =>
         'Full Github repo url or shorthand of username/repository.  You can pass multiple url args.',
 );
 
+option org => (
+    is            => 'ro',
+    isa           => ArrayRef,
+    format        => 's@',
+    required      => 0,
+    documentation => 'An organization.  You can pass multiple url args.',
+);
+
 has _report => (
     is          => 'ro',
     isa         => HashRef,
@@ -134,13 +144,39 @@ sub _build_report {
 
     my %report;
 
-    foreach my $url ( @{ $self->url } ) {
+    # Where we put all urls (from --url AND/OR --org)
+    my @urls = ();
+
+    # Where will go urls found from --org
+    my @org_urls = ();
+    if ( $self->org ) {
+        foreach my $org ( @{ $self->org } ) {
+            my $repos  = Pithub::Repos->new;
+            my $result = $repos->list( org => $org );
+
+            $result->auto_pagination(1);
+
+            while ( my $row = $result->next ) {
+                push @org_urls, $row->{full_name};
+            }
+        }
+    }
+
+    # Merge --org urls with --url urls and clean dups
+    push @urls, @org_urls;
+    if ( $self->url ) {
+        push @urls, @{ $self->url };
+    }
+    @urls = uniq @urls;
+
+    foreach my $url (@urls) {
         my $repo = GitHub::MergeVelocity::Repository->new(
             github_client => $self->_github_client,
             url           => $url,
         );
         $report{$url} = $repo;
     }
+
     return \%report;
 }
 
@@ -165,6 +201,8 @@ sub print_report {
 
     my @repos = map { $self->_repository_for_url($_) } $self->_report_urls;
 
+    return unless @repos;
+
     foreach my $repository (
         sort { $b->report->average_velocity <=> $a->report->average_velocity }
         @repos
@@ -216,7 +254,7 @@ GitHub::MergeVelocity - Determine how quickly your pull request might get merged
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 SYNOPSIS
 
