@@ -1,10 +1,10 @@
 package GitHub::MergeVelocity::Repository::Statistics;
-our $VERSION = '0.000008';
-use strict;
-use warnings;
+
+use Moo;
+
+our $VERSION = '0.000009';
 
 use Math::Round qw( nearest round );
-use Moo;
 use Types::Standard qw( Bool Int );
 
 has average_velocity => (
@@ -77,7 +77,7 @@ GitHub::MergeVelocity::Repository::Statistics - Pull request statistics for a gi
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 AUTHOR
 
